<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Mississippi";
    var qsoPartyUrl = "http://www.arrlmiss.org/";
    var overlayUrl = "http://www.no5w.com/OverlayMississippiRev4.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Adams", "ada");
  countySelection.options[1] = new Option("Alcorn", "alc");
  countySelection.options[2] = new Option("Amite", "ami");
  countySelection.options[3] = new Option("Attala", "att");
  countySelection.options[4] = new Option("Benton", "ben");
  countySelection.options[5] = new Option("Bolivar", "bol");
  countySelection.options[6] = new Option("Calhoun", "cal");
  countySelection.options[7] = new Option("Carroll", "car");
  countySelection.options[8] = new Option("Chickasaw", "chi");
  countySelection.options[9] = new Option("Choctaw", "cho");
  countySelection.options[10] = new Option("Claiborne", "clb");
  countySelection.options[11] = new Option("Clarke", "clk");
  countySelection.options[12] = new Option("Clay", "cla");
  countySelection.options[13] = new Option("Coahoma", "coa");
  countySelection.options[14] = new Option("Copiah", "cop");
  countySelection.options[15] = new Option("Covington", "cov");
  countySelection.options[16] = new Option("DeSoto", "des");
  countySelection.options[17] = new Option("Forrest", "for");
  countySelection.options[18] = new Option("Franklin", "fra");
  countySelection.options[19] = new Option("George", "geo");
  countySelection.options[20] = new Option("Greene", "grn");
  countySelection.options[21] = new Option("Grenada", "gre");
  countySelection.options[22] = new Option("Hancock", "han");
  countySelection.options[23] = new Option("Harrison", "har");
  countySelection.options[24] = new Option("Hinds", "hin");
  countySelection.options[25] = new Option("Holmes", "hol");
  countySelection.options[26] = new Option("Humphreys", "hum");
  countySelection.options[27] = new Option("Issaquena", "iss");
  countySelection.options[28] = new Option("Itawamba", "ita");
  countySelection.options[29] = new Option("Jackson", "jac");
  countySelection.options[30] = new Option("Jasper", "jas");
  countySelection.options[31] = new Option("Jefferson", "jef");
  countySelection.options[32] = new Option("JeffersonDavis", "jdv");
  countySelection.options[33] = new Option("Jones", "jon");
  countySelection.options[34] = new Option("Kemper", "kem");
  countySelection.options[35] = new Option("Lafayette", "laf");
  countySelection.options[36] = new Option("Lamar", "lam");
  countySelection.options[37] = new Option("Lauderdale", "lau");
  countySelection.options[38] = new Option("Lawrence", "law");
  countySelection.options[39] = new Option("Leake", "lea");
  countySelection.options[40] = new Option("Lee", "lee");
  countySelection.options[41] = new Option("Leflore", "lef");
  countySelection.options[42] = new Option("Lincoln", "lin");
  countySelection.options[43] = new Option("Lowndes", "low");
  countySelection.options[44] = new Option("Madison", "mad");
  countySelection.options[45] = new Option("Marion", "mrn");
  countySelection.options[46] = new Option("Marshall", "mar");
  countySelection.options[47] = new Option("Monroe", "mon");
  countySelection.options[48] = new Option("Montgomery", "mgy");
  countySelection.options[49] = new Option("Neshoba", "nes");
  countySelection.options[50] = new Option("Newton", "new");
  countySelection.options[51] = new Option("Noxubee", "nox");
  countySelection.options[52] = new Option("Oktibbeha", "okt");
  countySelection.options[53] = new Option("Panola", "pan");
  countySelection.options[54] = new Option("PearlRiver", "pea");
  countySelection.options[55] = new Option("Perry", "per");
  countySelection.options[56] = new Option("Pike", "pik");
  countySelection.options[57] = new Option("Pontotoc", "pon");
  countySelection.options[58] = new Option("Prentiss", "pre");
  countySelection.options[59] = new Option("Quitman", "qui");
  countySelection.options[60] = new Option("Rankin", "ran");
  countySelection.options[61] = new Option("Scott", "sco");
  countySelection.options[62] = new Option("Sharkey", "sha");
  countySelection.options[63] = new Option("Simpson", "sim");
  countySelection.options[64] = new Option("Smith", "smi");
  countySelection.options[65] = new Option("Stone", "sto");
  countySelection.options[66] = new Option("Sunflower", "sun");
  countySelection.options[67] = new Option("Tallahatchie", "tal");
  countySelection.options[68] = new Option("Tate", "tat");
  countySelection.options[69] = new Option("Tippah", "tip");
  countySelection.options[70] = new Option("Tishomingo", "tis");
  countySelection.options[71] = new Option("Tunica", "tun");
  countySelection.options[72] = new Option("Union", "uni");
  countySelection.options[73] = new Option("Walthall", "wal");
  countySelection.options[74] = new Option("Warren", "war");
  countySelection.options[75] = new Option("Washington", "was");
  countySelection.options[76] = new Option("Wayne", "way");
  countySelection.options[77] = new Option("Webster", "web");
  countySelection.options[78] = new Option("Wilkinson", "wil");
  countySelection.options[79] = new Option("Winston", "win");
  countySelection.options[80] = new Option("Yalobusha", "yal");
  countySelection.options[81] = new Option("Yazoo", "yaz");
  addMarker(31.47060000, -91.40440000, "Adams", "ada");
  addMarker(34.87580000, -88.59350000, "Alcorn", "alc");
  addMarker(31.17430000, -90.82070000, "Amite", "ami");
  addMarker(33.08270000, -89.64120000, "Attala", "att");
  addMarker(34.78900000, -89.18480000, "Benton", "ben");
  addMarker(33.82500000, -90.94470000, "Bolivar", "bol");
  addMarker(33.94190000, -89.32390000, "Calhoun", "cal");
  addMarker(33.44570000, -89.91000000, "Carroll", "car");
  addMarker(33.90680000, -88.95540000, "Chickasaw", "chi");
  addMarker(33.32100000, -89.27110000, "Choctaw", "cho");
  addMarker(32.00550000, -90.98130000, "Claiborne", "clb");
  addMarker(32.02710000, -88.67280000, "Clarke", "clk");
  addMarker(33.65930000, -88.75400000, "Clay", "cla");
  addMarker(34.25530000, -90.67840000, "Coahoma", "coa");
  addMarker(31.86770000, -90.42220000, "Copiah", "cop");
  addMarker(31.61530000, -89.57750000, "Covington", "cov");
  addMarker(34.85180000, -90.01840000, "DeSoto", "des");
  addMarker(31.17210000, -89.29480000, "Forrest", "for");
  addMarker(31.46570000, -90.89540000, "Franklin", "fra");
  addMarker(30.86650000, -88.64880000, "George", "geo");
  addMarker(31.21670000, -88.63370000, "Greene", "grn");
  addMarker(33.78720000, -89.82190000, "Grenada", "gre");
  addMarker(30.40320000, -89.49840000, "Hancock", "han");
  addMarker(30.41580000, -89.06840000, "Harrison", "har");
  addMarker(32.31110000, -90.39710000, "Hinds", "hin");
  addMarker(33.12730000, -90.09030000, "Holmes", "hol");
  addMarker(33.12600000, -90.53180000, "Humphreys", "hum");
  addMarker(32.71130000, -90.95270000, "Issaquena", "iss");
  addMarker(34.27600000, -88.35060000, "Itawamba", "ita");
  addMarker(30.44110000, -88.63450000, "Jackson", "jac");
  addMarker(32.01320000, -89.11660000, "Jasper", "jas");
  addMarker(31.74000000, -91.05090000, "Jefferson", "jef");
  addMarker(31.58230000, -89.78140000, "JeffersonDavis", "jdv");
  addMarker(31.62900000, -89.17200000, "Jones", "jon");
  addMarker(32.75290000, -88.63160000, "Kemper", "kem");
  addMarker(34.35820000, -89.48380000, "Lafayette", "laf");
  addMarker(31.20830000, -89.50110000, "Lamar", "lam");
  addMarker(32.40120000, -88.65230000, "Lauderdale", "lau");
  addMarker(31.54520000, -90.10210000, "Lawrence", "law");
  addMarker(32.75390000, -89.52410000, "Leake", "lea");
  addMarker(34.29200000, -88.68370000, "Lee", "lee");
  addMarker(33.52340000, -90.27760000, "Leflore", "lef");
  addMarker(31.53340000, -90.49070000, "Lincoln", "lin");
  addMarker(33.51640000, -88.46010000, "Lowndes", "low");
  addMarker(32.64250000, -90.09070000, "Madison", "mad");
  addMarker(31.21680000, -89.84720000, "Marion", "mrn");
  addMarker(34.74510000, -89.48500000, "Marshall", "mar");
  addMarker(33.86980000, -88.46220000, "Monroe", "mon");
  addMarker(33.48170000, -89.58380000, "Montgomery", "mgy");
  addMarker(32.75450000, -89.11680000, "Neshoba", "nes");
  addMarker(32.40030000, -89.11830000, "Newton", "new");
  addMarker(33.10720000, -88.55910000, "Noxubee", "nox");
  addMarker(33.42480000, -88.87880000, "Oktibbeha", "okt");
  addMarker(34.35690000, -89.95900000, "Panola", "pan");
  addMarker(30.73650000, -89.59650000, "PearlRiver", "pea");
  addMarker(31.17200000, -88.99020000, "Perry", "per");
  addMarker(31.17490000, -90.40400000, "Pike", "pik");
  addMarker(34.22710000, -89.03550000, "Pontotoc", "pon");
  addMarker(34.61020000, -88.53280000, "Prentiss", "pre");
  addMarker(34.29160000, -90.29270000, "Quitman", "qui");
  addMarker(32.32010000, -89.99230000, "Rankin", "ran");
  addMarker(32.42800000, -89.55310000, "Scott", "sco");
  addMarker(32.87980000, -90.81090000, "Sharkey", "sha");
  addMarker(31.90120000, -89.95040000, "Simpson", "sim");
  addMarker(32.00220000, -89.52390000, "Smith", "smi");
  addMarker(30.77900000, -89.11300000, "Stone", "sto");
  addMarker(33.62880000, -90.60750000, "Sunflower", "sun");
  addMarker(33.92920000, -90.18850000, "Tallahatchie", "tal");
  addMarker(34.66330000, -89.95630000, "Tate", "tat");
  addMarker(34.79610000, -88.90320000, "Tippah", "tip");
  addMarker(34.72940000, -88.23190000, "Tishomingo", "tis");
  addMarker(34.65790000, -90.39350000, "Tunica", "tun");
  addMarker(34.48170000, -88.99090000, "Union", "uni");
  addMarker(31.17570000, -90.04840000, "Walthall", "wal");
  addMarker(32.34860000, -90.86420000, "Warren", "war");
  addMarker(33.26910000, -90.95730000, "Washington", "was");
  addMarker(31.66360000, -88.69640000, "Wayne", "way");
  addMarker(33.59960000, -89.26270000, "Webster", "web");
  addMarker(31.18590000, -91.34790000, "Wilkinson", "wil");
  addMarker(33.10280000, -89.06600000, "Winston", "win");
  addMarker(34.02970000, -89.71950000, "Yalobusha", "yal");
  addMarker(32.76270000, -90.36280000, "Yazoo", "yaz");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

